@@ -341,6 +341,9 @@ def map_all_protrusion_indices(psaia_config_file, pdb_dataset, pkl_dataset, prun
         work_filenames = [os.path.join(pdb_dataset, db.get_pdb_code(work_key).upper(), work_key)
                           for work_key in work_keys]
 
+    # Remove any duplicate filenames
+    work_filenames = list(set(work_filenames))
+
     # Exit early if no inputs need to processed
     num_inputs = len(work_filenames)
     if num_inputs == 0:
@@ -385,6 +388,9 @@ def map_all_pssms(pkl_dataset, pruned_dataset, blastdb, output_dir, num_cpus, so
         work_filenames = [os.path.join(pkl_dataset, db.get_pdb_code(work_key)[1:3].upper(), work_key + ext)
                           for work_key in work_keys]
 
+    # Remove any duplicate filenames
+    work_filenames = list(set(work_filenames))
+
     # Reserve an equally-sized portion of the full work load for a given rank in the MPI world
     work_filename_rank_batches = slice_list(work_filenames, size)
     work_filenames = work_filename_rank_batches[rank]
@@ -437,6 +443,7 @@ def map_all_profile_hmms(pkl_dataset, pruned_dataset, output_dir, hhsuite_db, nu
                                                                                    len(produced_keys), len(work_keys)))
 
         # Write out a local file containing all work filenames
+        work_filenames = list(set(work_filenames))  # Remove any duplicate filenames
         temp_df = pd.DataFrame({'filename': work_filenames})
         temp_df.to_csv(f'{source_type}_work_filenames.csv')
         logging.info('File containing work filenames written to storage. Exiting...')
@@ -444,6 +451,7 @@ def map_all_profile_hmms(pkl_dataset, pruned_dataset, output_dir, hhsuite_db, nu
     # Read from previously-created work filenames CSV
     else:
         work_filenames = pd.read_csv(f'{source_type}_work_filenames.csv').iloc[:, 1].to_list()
+        work_filenames = list(set(work_filenames))  # Remove any duplicate filenames
 
         # Reserve an equally-sized portion of the full work load for a given rank in the MPI world
         work_filename_rank_batches = slice_list(work_filenames, size)
